
import QtQuick 1.1
import Qt3D 1.0
import Qt3D.Shapes 1.0
import Physics 1.0 as Physics

Rectangle {
    id : window
    width : 800
    height : 480

    Viewport {
        id : viewport
        width : parent.width
        height : parent.height
        navigation : true
        picking : true
        showPicking: false

        camera: Camera {
            id : camera
            center : Qt.vector3d(0, 0, 0)
            eye: Qt.vector3d(0, 0, 50)
        }

        // There must be a world.
        Physics.World3D {
            id : world
            gravity : Qt.vector3d(0,-9.81,0);
            showBounds: true
        }

        Sphere
        {
            id : ball

            effect: Effect {
                color: "yellow"
            }
            transform: Physics.Body3D {
                id : ballBody
                objectName: "The Amazing Ball"
                linearVelocity.x : 5
                linearVelocity.z : 1
                mass : 1
                // Some bouncyness
                restitution : .4
                friction : 0.4

                shape : Physics.Body3D.ShapeSphere
                bounds : Qt.vector3d(1, 1, 1)
            }
        }

        // But the ball... will face resistance
        Cube
        {
            id : floor
            objectName : "floor"
            x : 0
            y : -5
            z : 0

            transform : [
                Scale3D {
                    scale : Qt.vector3d(50, 1, 10)
                },

                Physics.Body3D {
                    target : floor

                    mass : 0
                    shape : Physics.Body3D.ShapeBox
                    friction : 1
                    restitution : 0.5
                    bounds : Qt.vector3d(50, 1, 10)

                    collisionEventEnabled: true
                    onCollision: {
                        console.log("Oh my! I was hit by " + collision.body.objectName);
                        console.log("With crushing force of " + collision.force + " kilonewtons!");
                        collision.accepted = true
                    }
                }
            ]
        }
    }
}
